==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/kgp-BR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM, y G",
    GyMMMEd => "E, d 'ne' MMM, y G",
    GyMMMd => "d 'ne' MMM, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d 'ne' MMM",
    MMMMEd => "E, d 'ne' MMMM",
    "MMMMW-count-one" => "'sim\N{U+1ef9}n\N{U+1ef9}' W 'ne' MMMM",
    "MMMMW-count-other" => "'sim\N{U+1ef9}n\N{U+1ef9}' W 'ne' MMMM",
    MMMMd => "d 'ne' MMMM",
    MMMd => "d 'ne' MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MMM, y",
    yMMMEd => "E, d 'ne' MMM, y",
    yMMMM => "MMMM, y",
    yMMMMEd => "E, d 'ne' MMMM, y",
    yMMMMd => "d 'ne' MMMM, y",
    yMMMd => "d 'ne' MMM, y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ, y",
    yQQQQ => "QQQQ, y",
    "yw-count-one" => "'sim\N{U+1ef9}n\N{U+1ef9}' w, Y",
    "yw-count-other" => "'sim\N{U+1ef9}n\N{U+1ef9}' w, Y",
  },
  code => "kgp-BR",
  date_format_full => "EEEE, d 'ne' MMMM, y",
  date_format_long => "d 'ne' MMMM, y",
  date_format_medium => "d 'ne' MMM, y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pir.",
    "r\N{U+00e9}g.",
    "t\N{U+1ebd}g.",
    "v\N{U+1ebd}n.",
    "p\N{U+00e9}n.",
    "sav.",
    "num.",
  ],
  day_format_narrow => [
    "P.",
    "R.",
    "T.",
    "V.",
    "P.",
    "S.",
    "N.",
  ],
  day_format_wide => [
    "pir-kur\N{U+00e3}-h\N{U+00e1}",
    "r\N{U+00e9}gre-kur\N{U+00e3}-h\N{U+00e1}",
    "t\N{U+1ebd}gt\N{U+0169}-kur\N{U+00e3}-h\N{U+00e1}",
    "v\N{U+1ebd}nhk\N{U+00e3}gra-kur\N{U+00e3}-h\N{U+00e1}",
    "p\N{U+00e9}nkar-kur\N{U+00e3}-h\N{U+00e1}",
    "savnu",
    "num\N{U+0129}ggu",
  ],
  day_stand_alone_abbreviated => [
    "pir.",
    "r\N{U+00e9}g.",
    "t\N{U+1ebd}g.",
    "v\N{U+1ebd}n.",
    "p\N{U+00e9}n.",
    "sav.",
    "num.",
  ],
  day_stand_alone_narrow => [
    "P.",
    "R.",
    "T.",
    "V.",
    "P.",
    "S.",
    "N.",
  ],
  day_stand_alone_wide => [
    "pir-kur\N{U+00e3}-h\N{U+00e1}",
    "r\N{U+00e9}gre-kur\N{U+00e3}-h\N{U+00e1}",
    "t\N{U+1ebd}gt\N{U+0169}-kur\N{U+00e3}-h\N{U+00e1}",
    "v\N{U+1ebd}nhk\N{U+00e3}gra-kur\N{U+00e3}-h\N{U+00e1}",
    "p\N{U+00e9}nkar-kur\N{U+00e3}-h\N{U+00e1}",
    "savnu",
    "num\N{U+0129}ggu",
  ],
  era_abbreviated => [
    "C.j.",
    "C.kk.",
  ],
  era_narrow => [
    "C.j.",
    "C.kk.",
  ],
  era_wide => [
    "Cristo jo",
    "Cristo kar k\N{U+1ef9}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kaingang",
  month_format_abbreviated => [
    "1Ky.",
    "2Ky.",
    "3Ky.",
    "4Ky.",
    "5Ky.",
    "6Ky.",
    "7Ky.",
    "8Ky.",
    "9Ky.",
    "10Ky.",
    "11Ky.",
    "12Ky.",
  ],
  month_format_narrow => [
    "1K",
    "2K",
    "3K",
    "4K",
    "5K",
    "6K",
    "7K",
    "8K",
    "9K",
    "10K",
    "11K",
    "12K",
  ],
  month_format_wide => [
    "1-Kys\N{U+00e3}",
    "2-Kys\N{U+00e3}",
    "3-Kys\N{U+00e3}",
    "4-Kys\N{U+00e3}",
    "5-Kys\N{U+00e3}",
    "6-Kys\N{U+00e3}",
    "7-Kys\N{U+00e3}",
    "8-Kys\N{U+00e3}",
    "9-Kys\N{U+00e3}",
    "10-Kys\N{U+00e3}",
    "11-Kys\N{U+00e3}",
    "12-Kys\N{U+00e3}",
  ],
  month_stand_alone_abbreviated => [
    "1Ky.",
    "2Ky.",
    "3Ky.",
    "4Ky.",
    "5Ky.",
    "6Ky.",
    "7Ky.",
    "8Ky.",
    "9Ky.",
    "10Ky.",
    "11Ky.",
    "12Ky.",
  ],
  month_stand_alone_narrow => [
    "1K",
    "2K",
    "3K",
    "4K",
    "5K",
    "6K",
    "7K",
    "8K",
    "9K",
    "10K",
    "11K",
    "12K",
  ],
  month_stand_alone_wide => [
    "1-Kys\N{U+00e3}",
    "2-Kys\N{U+00e3}",
    "3-Kys\N{U+00e3}",
    "4-Kys\N{U+00e3}",
    "5-Kys\N{U+00e3}",
    "6-Kys\N{U+00e3}",
    "7-Kys\N{U+00e3}",
    "8-Kys\N{U+00e3}",
    "9-Kys\N{U+00e3}",
    "10-Kys\N{U+00e3}",
    "11-Kys\N{U+00e3}",
    "12-Kys\N{U+00e3}",
  ],
  name => "Kaingang Brazil",
  native_language => "kanhg\N{U+00e1}g",
  native_name => "kanhg\N{U+00e1}g Mrasir",
  native_script => undef,
  native_territory => "Mrasir",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "2\N{U+1d4d}\N{U+1d49} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "3\N{U+207f}\N{U+02b0} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "4\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "2\N{U+1d4d}\N{U+1d49} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "3\N{U+207f}\N{U+02b0} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "4\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
  ],
  script => undef,
  territory => "Brazil",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/kgp-BR.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM, y G",
    GyMMMEd => "E, d 'ne' MMM, y G",
    GyMMMd => "d 'ne' MMM, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d 'ne' MMM",
    MMMMEd => "E, d 'ne' MMMM",
    "MMMMW-count-one" => "'sim\N{U+1ef9}n\N{U+1ef9}' W 'ne' MMMM",
    "MMMMW-count-other" => "'sim\N{U+1ef9}n\N{U+1ef9}' W 'ne' MMMM",
    MMMMd => "d 'ne' MMMM",
    MMMd => "d 'ne' MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MMM, y",
    yMMMEd => "E, d 'ne' MMM, y",
    yMMMM => "MMMM, y",
    yMMMMEd => "E, d 'ne' MMMM, y",
    yMMMMd => "d 'ne' MMMM, y",
    yMMMd => "d 'ne' MMM, y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ, y",
    yQQQQ => "QQQQ, y",
    "yw-count-one" => "'sim\N{U+1ef9}n\N{U+1ef9}' w, Y",
    "yw-count-other" => "'sim\N{U+1ef9}n\N{U+1ef9}' w, Y",
  },
  code => "kgp-BR",
  date_format_full => "EEEE, d 'ne' MMMM, y",
  date_format_long => "d 'ne' MMMM, y",
  date_format_medium => "d 'ne' MMM, y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pir.",
    "r\N{U+00e9}g.",
    "t\N{U+1ebd}g.",
    "v\N{U+1ebd}n.",
    "p\N{U+00e9}n.",
    "sav.",
    "num.",
  ],
  day_format_narrow => [
    "P.",
    "R.",
    "T.",
    "V.",
    "P.",
    "S.",
    "N.",
  ],
  day_format_wide => [
    "pir-kur\N{U+00e3}-h\N{U+00e1}",
    "r\N{U+00e9}gre-kur\N{U+00e3}-h\N{U+00e1}",
    "t\N{U+1ebd}gt\N{U+0169}-kur\N{U+00e3}-h\N{U+00e1}",
    "v\N{U+1ebd}nhk\N{U+00e3}gra-kur\N{U+00e3}-h\N{U+00e1}",
    "p\N{U+00e9}nkar-kur\N{U+00e3}-h\N{U+00e1}",
    "savnu",
    "num\N{U+0129}ggu",
  ],
  day_stand_alone_abbreviated => [
    "pir.",
    "r\N{U+00e9}g.",
    "t\N{U+1ebd}g.",
    "v\N{U+1ebd}n.",
    "p\N{U+00e9}n.",
    "sav.",
    "num.",
  ],
  day_stand_alone_narrow => [
    "P.",
    "R.",
    "T.",
    "V.",
    "P.",
    "S.",
    "N.",
  ],
  day_stand_alone_wide => [
    "pir-kur\N{U+00e3}-h\N{U+00e1}",
    "r\N{U+00e9}gre-kur\N{U+00e3}-h\N{U+00e1}",
    "t\N{U+1ebd}gt\N{U+0169}-kur\N{U+00e3}-h\N{U+00e1}",
    "v\N{U+1ebd}nhk\N{U+00e3}gra-kur\N{U+00e3}-h\N{U+00e1}",
    "p\N{U+00e9}nkar-kur\N{U+00e3}-h\N{U+00e1}",
    "savnu",
    "num\N{U+0129}ggu",
  ],
  era_abbreviated => [
    "C.j.",
    "C.kk.",
  ],
  era_narrow => [
    "C.j.",
    "C.kk.",
  ],
  era_wide => [
    "Cristo jo",
    "Cristo kar k\N{U+1ef9}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kaingang",
  month_format_abbreviated => [
    "1Ky.",
    "2Ky.",
    "3Ky.",
    "4Ky.",
    "5Ky.",
    "6Ky.",
    "7Ky.",
    "8Ky.",
    "9Ky.",
    "10Ky.",
    "11Ky.",
    "12Ky.",
  ],
  month_format_narrow => [
    "1K",
    "2K",
    "3K",
    "4K",
    "5K",
    "6K",
    "7K",
    "8K",
    "9K",
    "10K",
    "11K",
    "12K",
  ],
  month_format_wide => [
    "1-Kys\N{U+00e3}",
    "2-Kys\N{U+00e3}",
    "3-Kys\N{U+00e3}",
    "4-Kys\N{U+00e3}",
    "5-Kys\N{U+00e3}",
    "6-Kys\N{U+00e3}",
    "7-Kys\N{U+00e3}",
    "8-Kys\N{U+00e3}",
    "9-Kys\N{U+00e3}",
    "10-Kys\N{U+00e3}",
    "11-Kys\N{U+00e3}",
    "12-Kys\N{U+00e3}",
  ],
  month_stand_alone_abbreviated => [
    "1Ky.",
    "2Ky.",
    "3Ky.",
    "4Ky.",
    "5Ky.",
    "6Ky.",
    "7Ky.",
    "8Ky.",
    "9Ky.",
    "10Ky.",
    "11Ky.",
    "12Ky.",
  ],
  month_stand_alone_narrow => [
    "1K",
    "2K",
    "3K",
    "4K",
    "5K",
    "6K",
    "7K",
    "8K",
    "9K",
    "10K",
    "11K",
    "12K",
  ],
  month_stand_alone_wide => [
    "1-Kys\N{U+00e3}",
    "2-Kys\N{U+00e3}",
    "3-Kys\N{U+00e3}",
    "4-Kys\N{U+00e3}",
    "5-Kys\N{U+00e3}",
    "6-Kys\N{U+00e3}",
    "7-Kys\N{U+00e3}",
    "8-Kys\N{U+00e3}",
    "9-Kys\N{U+00e3}",
    "10-Kys\N{U+00e3}",
    "11-Kys\N{U+00e3}",
    "12-Kys\N{U+00e3}",
  ],
  name => "Kaingang Brazil",
  native_language => "kanhg\N{U+00e1}g",
  native_name => "kanhg\N{U+00e1}g Mrasir",
  native_script => undef,
  native_territory => "Mrasir",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "2\N{U+1d4d}\N{U+1d49} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "3\N{U+207f}\N{U+02b0} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "4\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "2\N{U+1d4d}\N{U+1d49} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "3\N{U+207f}\N{U+02b0} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
    "4\N{U+207f} kys\N{U+00e3}-t\N{U+1ebd}gt\N{U+0169}",
  ],
  script => undef,
  territory => "Brazil",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
